import 'package:flutter/material.dart';
import 'package:masamune_flutter/masamune_flutter.dart';
import 'uitextfieldcontrollermixin.dart';

/// Mixins for using forms on pages.
abstract class UIFormMixin extends UITextFieldControllerMixin {
  /// Key for form.
  final formKey = GlobalKey<FormState>();

  /// Data for the form.
  IDataDocument get form => this._form;
  final _form = DataDocument(DefaultPath.formData);

  /// Executed when the widget is unloaded.
  ///
  /// Override and use.
  ///
  /// [context]: Build context.
  @protected
  @mustCallSuper
  void onLoad(BuildContext context) {
    super.onLoad(context);
    this._form.clear();
  }

  /// Validate and save the data in the form.
  ///
  /// Returns True if the validation is successful.
  bool validateAndSave() {
    if (this.formKey == null || this.formKey.currentState == null) return false;
    if (!this.formKey.currentState.validate()) return false;
    this._form.clear();
    this.formKey.currentState.save();
    return true;
  }
}
