import 'dart:async';

import 'package:flutter/material.dart';
import 'package:masamune_flutter/masamune_flutter.dart';

/// Mixin for using multiple text edit controllers.
abstract class UITextFieldControllerMixin extends UIPage {
  /// Text Editing Controller.
  final Map<String, TextEditingController> controllers = MapPool.get();

  /// Initialize the controller.
  ///
  /// [data]: Enter the controller key in the key and the initial value in the value.
  void init(Map<String, String> data) {
    data?.forEach((key, value) {
      if (isEmpty(key)) return;
      controllers[key] = TextEditingController(text: value ?? Const.empty);
    });
  }

  /// Upload the controller text all at once.
  ///
  /// [data]: Data document for applying data to the controller.
  void update(FutureOr<IDataDocument> data) {
    if (data is Future<IDataDocument>) {
      data.then((value) {
        value?.forEach((key, value) {
          if (isEmpty(key) || !controllers.containsKey(key)) return;
          controllers[key].text = value?.toString() ?? Const.empty;
        });
      });
    } else if (data is IDataDocument) {
      data?.forEach((key, value) {
        if (isEmpty(key) || !controllers.containsKey(key)) return;
        controllers[key].text = value?.toString() ?? Const.empty;
      });
    }
  }
}
